==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Arbeit</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Leben</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Andere</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Einen Tag vor Beginn</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Erinnere mich morgen</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Erinnere mich später</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 Min. später</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 Stunde später</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 Stunden später</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Morgen</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Terminerinnerung</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 bis %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Heute</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Einen Tag vor Beginn</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Schließen</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Erinnere mich morgen</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Erinnere mich später</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Terminerinnerung</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 bis %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Heute</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Morgen</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Arbeit</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Leben</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Andere</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Einen Tag vor Beginn</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Erinnere mich morgen</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Erinnere mich später</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 Min. später</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 Stunde später</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 Stunden später</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Morgen</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Terminerinnerung</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 bis %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Heute</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
